awkward-array
=============

.. inclusion-marker-1-do-not-remove

Manipulate jagged, chunky, and/or bitmasked arrays as easily as Numpy.

.. inclusion-marker-1-5-do-not-remove

(...)

.. inclusion-marker-2-do-not-remove

Installation
============

Install awkward-array like any other Python package:

.. code-block:: bash

    pip install awkward

or similar (use ``sudo``, ``--user``, ``virtualenv``, or pip-in-conda if you wish).

Strict dependencies:
====================

- `Python <http://docs.python-guide.org/en/latest/starting/installation/>`__ (2.7+, 3.4+)
- `Numpy <https://scipy.org/install.html>`__

Recommended dependencies:
=========================

- `Numba and LLVM <http://numba.pydata.org/numba-doc/latest/user/installing.html>`__ to JIT-compile functions (requires a particular version of LLVM, follow instructions)
- `Dask <http://dask.pydata.org/en/latest/install.html>`__ to distribute work on arrays
- `bcolz <http://bcolz.blosc.org/en/latest/install.html>`__ for on-the-fly compression
- `pyarrow and Arrow-C++ <https://arrow.apache.org/docs/python/install.html>`__ for interoperability with other applications and fast Parquet reading/writing

.. inclusion-marker-3-do-not-remove

Tutorial
========

**Table of contents:**

(...)

Interactive tutorial
====================

.. Run `this tutorial <https://mybinder.org/v2/gh/scikit-hep/histbook/master?filepath=binder%2Ftutorial.ipynb>`__ on Binder.

(...)

Reference documentation
=======================

(...)

Getting started
---------------

Install awkward-arrays...
